# PyRestart

Module that can make new instance of itself, normally used to restart a script, I think you can get it [here](https://pypi.org/project/pyrestart/)
<br>
To get help, use the help() function and pass the function that you need help with


## Function list
newRestart

new_restart